# Наблюдаемость

## Ведение журнала

Структурированные журналы с поддержкой выборки и редактирования.

## Метрики

Выставьте счетчики и распределения задержек (`p50/p95/p99`).

## Трассировка

Используйте распространение контекста трассировки для отслеживания межсервисных запросов.

## Здоровье

Используйте проверки работоспособности/готовности/запуска для систем оркестрации.